---
name: Bug report
about: Create a useful report to help us improve ramses_rf
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of the bug.

**To Reproduce**
Steps to reproduce the behaviour (for example):
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

Please provide enough details. For example, if you are having an issue with a device, provide details of the model and specs

**Expected behaviour**
A clear and concise description of what you expected to happen.

**Please include the following information:**
 - your **RF Gateway** hardware type, firmware and connection (USB, MQTT)
 - output from the **Serial Console**, if applicable
 - contemporaneous portion of the **packet.log**, preferably for several hours

**Screenshots**
Only if applicable, add screenshots to help explain your problem. Do not provide a screenshot as an alternative to providing the above information.

**Additional context**
Add any other context about the problem here, such as the make/model of the device etc.
